<?php
error_reporting(E_ALL);
ini_set('display_errors', 1);

require_once 'auth.php';
requireLogin();
$user = currentUser();
$groupId = (int)($user['group_id'] ?? 0);
if ($groupId < 9) {
    die("Unauthorized");
}



require_once '../config/db.php';

// ---- Bulletproof MySQL DATE validator ----
function valid_mysql_date($date) {
    return preg_match('/^\d{4}-\d{2}-\d{2}$/', $date) ? $date : null;
}

$eventTypes = $db->query("SELECT DISTINCT event_type FROM events WHERE is_deleted = 0")->fetch_all(MYSQLI_ASSOC);
$countries = $db->query("SELECT * FROM countries ORDER BY name ASC")->fetch_all(MYSQLI_ASSOC);

$message = '';
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $event_type = $_POST['event_type'] ?? '';
    $event_id = (int)($_POST['event_id'] ?? 0);
    $label = trim($_POST['label'] ?? '');
    $air_date = valid_mysql_date($_POST['air_date'] ?? '');
    $promo_deadline = valid_mysql_date($_POST['promo_deadline'] ?? '');
    $overall_seg_limit = (int)($_POST['overall_seg_limit'] ?? 0);
    $character_seg_limit = (int)($_POST['character_seg_limit'] ?? 0);
    $country_id = (int)($_POST['country_id'] ?? 0);
    $venue_id = (int)($_POST['venue_id'] ?? 0);
    $preview_intro = $_POST['preview_intro'] ?? '';
    $preview_conclusion = $_POST['preview_conclusion'] ?? '';
    $custom_image_path = '';
    if (!empty($_FILES['custom_image']['name'])) {
        $targetDir = $_SERVER['DOCUMENT_ROOT'] . '/uploads/event-images/';
        if (!file_exists($targetDir)) mkdir($targetDir, 0755, true);

        $filename = time() . "_" . basename($_FILES['custom_image']['name']);
        $targetFile = $targetDir . $filename;

        if (move_uploaded_file($_FILES['custom_image']['tmp_name'], $targetFile)) {
            $custom_image_path = $filename;
        } else {
            error_log("Failed to move uploaded file to: " . $targetFile);
        }
    }

    $is_deleted = 0;
    $booking_status = 'Pre-Booking';

    // ---- DATE VALIDATION ----
    if (!$air_date) {
        $message = "<p class='notice error'>Invalid Air Date. Please use the date picker.</p>";
    } elseif ($promo_deadline === null && !empty($_POST['promo_deadline'])) {
        $message = "<p class='notice error'>Invalid Promo Deadline. Please use the date picker or leave blank.</p>";
    } else {
        // DEBUG (uncomment these lines to debug variable values before insert)
        // echo "<pre>";
        // echo "air_date: "; var_dump($air_date);
        // echo "promo_deadline: "; var_dump($promo_deadline);
        // echo "</pre>"; exit;

        $stmt = $db->prepare("INSERT INTO event_bookings (
            event_type, event_id, label, air_date, promo_deadline,
            overall_seg_limit, character_seg_limit, country_id, venue_id,
            custom_image_path, is_deleted, booking_status, preview_intro, preview_conclusion
        ) VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)");

        $stmt->bind_param(
            "sisssiiiisisss",
            $event_type,
            $event_id,
            $label,
            $air_date,
            $promo_deadline,
            $overall_seg_limit,
            $character_seg_limit,
            $country_id,
            $venue_id,
            $custom_image_path,
            $is_deleted,
            $booking_status,
            $preview_intro,
            $preview_conclusion
        );

        $stmt->execute();
        $message = "<p class='notice success'>Booking sheet created successfully.</p>";
        header("Location: booking_manager.php");
    }
}
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <title>Add Booking Sheet</title>
    <link rel="stylesheet" href="css/admin.css">
    <style>
    .form-row { margin-bottom: 1rem; }
    label { display: block; font-weight: bold; }
    .event-preview { margin-top: 1rem; }
    .event-preview img { max-height: 100px; }
    .notice.error { background: #ffdddd; color: #a00; padding: 10px; border-radius: 4px; margin-bottom: 1rem; }
    .notice.success { background: #e8ffe8; color: #080; padding: 10px; border-radius: 4px; margin-bottom: 1rem; }
    </style>
<link href="https://cdn.jsdelivr.net/npm/select2@4.1.0-rc.0/dist/css/select2.min.css" rel="stylesheet" />

</head>
<body>
<div class="dashboard-wrapper form-standard">

    <h2>Event Booking Management</h2>
    <?php echo $message; ?>
    <form method="post" enctype="multipart/form-data" id="bookingForm">
        <div class="form-row">
            <label>Event Type:</label>
            <select name="event_type" id="event_type" required>
                <option value="">- Select -</option>
                <?php foreach ($eventTypes as $type): ?>
                    <option value="<?php echo htmlspecialchars($type['event_type']); ?>"><?php echo htmlspecialchars($type['event_type']); ?></option>
                <?php endforeach; ?>
            </select>
        </div>

        <div class="form-row">
            <label>Event Name:</label>
            <select name="event_id" id="event_id" required>
                <option value="">- Select Event Type first -</option>
            </select>
        </div>

        <div class="form-row">
            <label>Label:</label>
            <input type="text" name="label">
        </div>

        <div class="form-row">
            <label>Air Date:</label>
            <input type="date" name="air_date" required>
        </div>

        <div class="form-row">
    <label>Promo Deadline:</label>
    <input type="date" name="promo_deadline" value="<?php echo date('Y-m-d'); ?>">
</div>

        <div class="form-row">
            <label>Overall Segment Limit:</label>
            <input type="number" name="overall_seg_limit" value="0" min="0">
        </div>

        <div class="form-row">
            <label>Character Segment Limit:</label>
            <input type="number" name="character_seg_limit" value="0" min="0">
        </div>

        <div class="form-row">
            <label>Country:</label>
            <select name="country_id" id="country_id" required>
                <option value="">- Select -</option>
                <?php foreach ($countries as $country): ?>
                    <option value="<?php echo $country['id']; ?>"><?php echo htmlspecialchars($country['name']); ?></option>
                <?php endforeach; ?>
            </select>
        </div>

        <div class="form-row">
            <label>Venue:</label>
            <select name="venue_id" id="venue_id" required>
                <option value="">- Select Country -</option>
            </select>
        </div>

        <div class="form-row event-preview">
            <label>Event Image:</label><i>Only upload a new event image IF you are not using the default show logo image.</i><br>
            <div id="eventImage"></div>
            <input type="file" name="custom_image" accept="image/*">
        </div>

        <button type="submit" class="button">Add Booking Sheet</button>
        <a href="booking_manager.php" class="button">Return to Booking Manager</a>
    </form>
</div>

<script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
<script>
$(document).ready(function () {
    $('#country_id').select2({ width: '100%' });
    $('#venue_id').select2({ width: '100%' });

    $('#event_type').on('change', function () {
        $.post('ajax_get_events.php', { type: $(this).val() }, function (data) {
            $('#event_id').html(data);
            $('#eventImage').html('');
        });
    });

    $('#event_id').on('change', function () {
        $.post('ajax_get_event_image.php', { id: $(this).val() }, function (data) {
            $('#eventImage').html(data);
        });
    });

    $('#country_id').on('change', function () {
        $.post('ajax_get_venues.php', { id: $(this).val() }, function (data) {
            $('#venue_id').html(data);
            // Re-initialize Select2 after updating venue options
            $('#venue_id').select2({ width: '100%' });
        });
    });
});
</script>

<script src="https://cdn.jsdelivr.net/npm/select2@4.1.0-rc.0/dist/js/select2.min.js"></script>
</body>
</html>