<?php

ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);

require_once 'auth.php';
requireLogin();
$user = currentUser();
$groupId = (int)($user['group_id'] ?? 0);
if ($groupId < 9) {
    die("Unauthorized");
}

require_once '../config/db.php';

$categoryQuery = $db->query("SELECT name FROM event_categories ORDER BY name ASC");
$availableCategories = [];
while ($row = $categoryQuery->fetch_assoc()) {
    $availableCategories[] = $row['name'];
}


$message = '';

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $name = trim($_POST['name']);
    $short_name = trim($_POST['short_name']);
    $event_type = $_POST['event_type'];
    $selectedCategories = $_POST['categories'] ?? ['NONE'];
    $categoryString = implode(',', array_map('trim', $selectedCategories));

    $image_path = '';
    if (!empty($_FILES['image']['name'])) {
        $targetDir = '../uploads/show-logos/';
        $filename = basename($_FILES['image']['name']);
        $targetFile = $targetDir . time() . "_" . $filename;

        if (move_uploaded_file($_FILES['image']['tmp_name'], $targetFile)) {
            $image_path = basename($targetFile);
        }
    }

    if ($name && $event_type) {
        $stmt = $db->prepare("INSERT INTO events (name, short_name, event_type, image_path, sort_order, categories, is_deleted, created_at) VALUES (?, ?, ?, ?, 0, ?, 0, NOW())");
$stmt->bind_param("sssss", $name, $short_name, $event_type, $image_path, $categoryString);

        $stmt->execute();
        header("Location: event_manager.php");
        exit;
    } else {
        $message = "<p class='notice error'>Please fill out all required fields.</p>";
    }
}
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <title>Add New Event</title>
    <link rel="stylesheet" href="css/admin.css">
</head>
<body>
    <div class="dashboard-wrapper">
        <h2>Add New Event</h2>
        <?php echo $message; ?>
        <form method="post" enctype="multipart/form-data">
            <b><label>Event Name:</b><br><input type="text" name="name" required></label><br><br>
            <b><label>Short Name:</b><br><input type="text" name="short_name"></label><br><br>
            <b><label>Event Type:</b><br>
                <select name="event_type" required>
                    <option value="">Select Type</option>
                    <option value="Non Aired/Streamed">Non Aired/Streamed</option>
                    <option value="On Air/Streaming/Flagship Shows">On Air/Streaming/Flagship Shows</option>
                    <option value="PPV/PLE Events">PPV/PLE Events</option>
                    <option value="Special Events">Special Events</option>
                </select>
            </label><br><br>     
    <b><label for="categories">Event Categories:</label></b><br>
    <select name="categories[]" id="categories" multiple size="6">
        <option value="NONE">None</option>
        <?php foreach ($availableCategories as $cat): ?>
            <option value="<?= htmlspecialchars($cat) ?>"><?= htmlspecialchars($cat) ?></option>
        <?php endforeach; ?>
    </select><br><br>
            <b><label>Upload Default Image:</b> <small style="color:gray;">Recommended size 300x150 or similar.</small><br><input type="file" name="image" accept="image/*"></label><br><br>
            <button type="submit" class="button">Add Event</button> 
<a href="event_manager.php" class="button" align="center">Back to Event Manager</a>
   
</form>
        
    </div>
</body>
</html>
