<?php
// Add this at the top if it's not already there
ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);
?>
<?php
require_once 'auth.php';
requireLogin();
require_once 'libs/site-settings-lib.php';


$logo = getSetting('dashboard_logo_url') ?: '/uploads/logos/default-logo.png';
$user = currentUser();
$charId = $_SESSION['active_character_id'] ?? null;
$charList = [];

if ($user['group_id'] >= 9) {
    // Admin/Webmaster: all ACTIVE characters (not deleted, not alumni)
    $stmt = $db->prepare("
        SELECT id, name
        FROM characters
        WHERE deleted = 0 AND alumni = 0
        ORDER BY name ASC
    ");
    $stmt->execute();
    $charList = $stmt->get_result()->fetch_all(MYSQLI_ASSOC);
} else {
    // Fan, Alumni, Handler: only characters assigned to user (active, injured, or alumni — but not deleted)
    $stmt = $db->prepare("
        SELECT c.id, c.name
        FROM characters c
        JOIN character_user_map map ON c.id = map.character_id
        WHERE map.user_id = ?
          AND c.deleted = 0
        ORDER BY c.name ASC
    ");
    $stmt->bind_param('i', $user['id']);
    $stmt->execute();
    $charList = $stmt->get_result()->fetch_all(MYSQLI_ASSOC);
}

?>

<!DOCTYPE html>
<html>
<head>
  <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>eFed Management Suite Admin Dashboard</title>
    <link rel="stylesheet" href="css/admin.css">
    <?php $favicon = getSetting('dashboard_favicon_url'); ?>
    <?php if ($favicon): ?>
        <link rel="icon" type="image/png" href="<?= htmlspecialchars($favicon) ?>">
    <?php endif; ?>

<style>
  @media (max-width: 768px) {
    #admin-sidebar {
      display: none;
      width: 100%;
      max-height: calc(100vh - 60px);
      overflow-y: auto;
      background-color: #222;
      position: static;
    }
@media (max-width: 768px) {
  .hide-on-mobile {
    display: none !important;
  }
}
    #admin-sidebar.open {
      display: block;
    }
    #menu-toggle {
      display: inline-block;
      background: none;
      border: none;
      color: white;
      font-size: 22px;
      cursor: pointer;
      margin-right: 10px;
    }
    #admin-content {
      margin-left: 0 !important;
      margin-top: 120px;
    }
    #dashboard-footer {
      left: 0 !important;
    }
  }

  @media (min-width: 769px) {
    #menu-toggle {
      display: none;
    }
  }
</style>
<script>
  function toggleSidebar() {
  const sidebar = document.getElementById('admin-sidebar');
  sidebar.classList.toggle('open');
  if (sidebar.classList.contains('open')) {
    window.scrollTo({ top: 0, behavior: 'smooth' });
  }
}


  // Collapse sidebar when a link is clicked in mobile view
  document.addEventListener('DOMContentLoaded', function () {
    var sidebar = document.getElementById('admin-sidebar');
    if (sidebar) {
      sidebar.querySelectorAll('a').forEach(function (link) {
        link.addEventListener('click', function () {
          if (window.innerWidth <= 768) {
            sidebar.classList.remove('open');
          }
        });
      });
    }
  });
</script>
</head>
<body>

<div id="admin-header">
  <button id="menu-toggle" onclick="toggleSidebar()">☰</button>
    <div class="hide-on-mobile">
        <img src="<?= htmlspecialchars($logo) ?>" alt="Logo" style="height: 40px;">
    </div>
  <div class="right-tools hide-on-mobile">
        Welcome, <?= htmlspecialchars($user['username']) ?>!
 </div><div>
        <form method="POST" action="character_context.php" style="display:inline;">
            <select name="character_id" onchange="this.form.submit();">
                <option value="">Select Character</option>
                <?php foreach ($charList as $char): ?>
                    <option value="<?= $char['id'] ?>" <?= $charId == $char['id'] ? 'selected' : '' ?>>
                        <?= htmlspecialchars($char['name'], ENT_QUOTES) ?>
                    </option>
                <?php endforeach; ?>
            </select>
        </form>
    </div>
</div>

<?php include 'sidebar.php'; ?>

<div id="admin-content">
    <iframe name="admin-frame" src="welcome.php"></iframe>
</div>

<div id="dashboard-footer">
    <?= getSetting('dashboard_footer_html') ?>
</div>

</body>
</html>
