<?php
// -------------------------------------------------
// edit_booking.php
// -------------------------------------------------
ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);

require_once 'auth.php';
requireLogin();
$user = currentUser();
$groupId = (int)($user['group_id'] ?? 0);
if ($groupId < 9) {
    die("Unauthorized");
}
require_once __DIR__ . '/../config/db.php';

$id = isset($_GET['id']) ? (int)$_GET['id'] : 0;
if (!$id) {
    die("<p>Invalid booking ID.</p>");
}

// Fetch booking
$stmt = $db->prepare("SELECT * FROM event_bookings WHERE id = ?");
$stmt->bind_param('i', $id);
$stmt->execute();
$booking = $stmt->get_result()->fetch_assoc();
$stmt->close();

if (!$booking) {
    die("<p>Booking not found.</p>");
}

$prevStatus = $booking['booking_status'];

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $label = trim($_POST['label'] ?? '');
    $air_date = $_POST['air_date'] ?? null;
    $promo_deadline = $_POST['promo_deadline'] ?? null;
    $overall_seg_limit = (int)($_POST['overall_seg_limit'] ?? 0);
    $character_seg_limit = (int)($_POST['character_seg_limit'] ?? 0);
    $booking_status = $_POST['booking_status'] ?? 'Booking';
    $preview_intro = $_POST['preview_intro'] ?? '';
    $preview_conclusion = $_POST['preview_conclusion'] ?? '';

    $stmt = $db->prepare("UPDATE event_bookings SET label=?, air_date=?, promo_deadline=?, overall_seg_limit=?, character_seg_limit=?, booking_status=?, preview_intro=?, preview_conclusion=? WHERE id=?");
    $stmt->bind_param('sssissssi', $label, $air_date, $promo_deadline, $overall_seg_limit, $character_seg_limit, $booking_status, $preview_intro, $preview_conclusion, $id);
    $stmt->execute();
    $stmt->close();
    
if (isset($_POST['delete']) && $_POST['delete'] == '1') {
    // Soft delete the booking
    $delStmt = $db->prepare("UPDATE event_bookings SET is_deleted = 1 WHERE id = ?");
    $delStmt->bind_param('i', $id);
    $delStmt->execute();
    $delStmt->close();

    // Optional: also soft-delete all associated matches
    $db->query("UPDATE event_matches SET is_deleted = 1 WHERE booking_id = {$id}");

    header("Location: booking_manager.php?deleted=1");
    exit;
}


// ────────────────────────────────────────────────────────
    // If status is changing *into* Public, record title changes
    // ────────────────────────────────────────────────────────
    if ($prevStatus !== 'Public' && $booking_status === 'Public') {
        // 1) Get the event name for storing in title_reigns.event_name
        $eventStmt = $db->prepare("
          SELECT e.name AS event_name
            FROM event_bookings eb
            JOIN events e ON eb.event_id = e.id
           WHERE eb.id = ?
           LIMIT 1
        ");
        $eventStmt->bind_param('i', $id);
        $eventStmt->execute();
        $evtResult = $eventStmt->get_result()->fetch_assoc();
        $eventName = $evtResult['event_name'] ?? '';
        $eventStmt->close();

        // 2) Fetch all matches with a title on the line
        $titleMatchStmt = $db->prepare("
          SELECT 
            m.id          AS match_id,
            m.match_name  AS match_name,
            m.title_id    AS title_id
          FROM event_matches m
          WHERE m.booking_id = ?
            AND m.title_id IS NOT NULL
        ");
        $titleMatchStmt->bind_param('i', $id);
        $titleMatchStmt->execute();
        $titleRes = $titleMatchStmt->get_result();

        while ($matchRow = $titleRes->fetch_assoc()) {
            $matchId   = (int)$matchRow['match_id'];
            $matchName = $matchRow['match_name'];
            $titleId   = (int)$matchRow['title_id'];

            // 3) Determine who won that match (result = 'win')
            $winStmt = $db->prepare("
              SELECT character_id
                FROM match_results
               WHERE match_id = ?
                 AND result = 'win'
               LIMIT 1
            ");
            $winStmt->bind_param('i', $matchId);
            $winStmt->execute();
            $winRes = $winStmt->get_result();
            $winnerRow = $winRes->fetch_assoc();
            $championAfter = $winnerRow['character_id'] ?? null;
            $winStmt->close();

            if (!$championAfter) {
                continue; // skip if no winner recorded
            }

            // 4) Look up the previous champion (titles.current_champion_id)
            $oldChampStmt = $db->prepare("
              SELECT current_champion_id
                FROM titles
               WHERE id = ?
            ");
            $oldChampStmt->bind_param('i', $titleId);
            $oldChampStmt->execute();
            $oldChampRow = $oldChampStmt->get_result()->fetch_assoc();
            $championBefore = $oldChampRow['current_champion_id'] ?? null;
            $oldChampStmt->close();

            // 5) Insert a new row into title_reigns
            $insertReign = $db->prepare("
              INSERT INTO title_reigns
                (title_id, event_name, match_name, change_date, champion_before, champion_after, summary)
              VALUES (?, ?, ?, ?, ?, ?, ?)
            ");
            $changeDate = $air_date; // booking's air_date
            $summary = "Auto‐recorded when show went Public";

            $insertReign->bind_param(
                'isssiis',
                $titleId,
                $eventName,
                $matchName,
                $changeDate,
                $championBefore,
                $championAfter,
                $summary
            );
            $insertReign->execute();
            $insertReign->close();

            // 6) Update titles.current_champion_id to the new champion
            $updateTitle = $db->prepare("
              UPDATE titles
                 SET current_champion_id = ?
               WHERE id = ?
            ");
            $updateTitle->bind_param('ii', $championAfter, $titleId);
            $updateTitle->execute();
            $updateTitle->close();
        }

        $titleMatchStmt->close();
    }
    // ────────────────────────────────────────────────────────

    if ($prevStatus === 'Public' && $booking_status !== 'Public') {
        $resultStmt = $db->prepare("SELECT character_id, result FROM match_results WHERE match_id IN (SELECT id FROM event_matches WHERE booking_id = ?)");
        $resultStmt->bind_param('i', $id);
        $resultStmt->execute();
        $res = $resultStmt->get_result();
        while ($row = $res->fetch_assoc()) {
            $cid = (int)$row['character_id'];
            $field = '';
            if ($row['result'] === 'win') $field = 'auto_wins';
            elseif ($row['result'] === 'loss') $field = 'auto_losses';
            elseif ($row['result'] === 'nc') $field = 'auto_ncs';

            if ($field) {
                $db->query("UPDATE win_loss_records SET {$field} = GREATEST({$field} - 1, 0), auto_matches = GREATEST(auto_matches - 1, 0) WHERE character_id = {$cid}");
            }
        }
        $resultStmt->close();
    }

    header("Location: booking_manager.php?updated=1");
    exit;
}
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <title>Edit Booking</title>
    <link rel="stylesheet" href="css/admin.css">
    <script src="../js/tinymce/tinymce.min.js"></script>
</head>
<body>
<div class="dashboard-wrapper">
    <h2>Edit Booking</h2>
    <form method="post">
        <label>Label:</label><br>
        <input type="text" name="label" value="<?= htmlspecialchars((string)($booking['label']), ENT_QUOTES, 'UTF-8') ?>"><br><br>

        <label>Air Date:</label><br>
        <input type="date" name="air_date" value="<?= htmlspecialchars((string)($booking['air_date']), ENT_QUOTES, 'UTF-8') ?>"><br><br>

        <label>Promo Deadline:</label><br>
        <input type="date" name="promo_deadline" value="<?= htmlspecialchars((string)($booking['promo_deadline']), ENT_QUOTES, 'UTF-8') ?>"><br><br>

        <label>Overall Segment Limit:</label><br>
        <input type="number" name="overall_seg_limit" value="<?= (int)$booking['overall_seg_limit'] ?>"><br><br>

        <label>Character Segment Limit:</label><br>
        <input type="number" name="character_seg_limit" value="<?= (int)$booking['character_seg_limit'] ?>"><br><br>

        <label>Booking Status:</label><br>
        <select name="booking_status">
            <?php foreach (["Pre-Booking", "On Hold", "Booking", "Public"] as $status): ?>
                <option value="<?= $status ?>" <?= $booking['booking_status'] === $status ? 'selected' : '' ?>>
                    <?= $status ?>
                </option>
            <?php endforeach; ?>
        </select><br><br>

        <label>Preview Introduction:</label><br>
        <textarea id="preview_intro" name="preview_intro" rows="5" style="width:100%;">
<?= htmlspecialchars((string)($booking['preview_intro']), ENT_QUOTES, 'UTF-8') ?>
        </textarea><br><br>

        <label>Preview Conclusion:</label><br>
        <textarea id="preview_conclusion" name="preview_conclusion" rows="5" style="width:100%;">
<?= htmlspecialchars((string)($booking['preview_conclusion']), ENT_QUOTES, 'UTF-8') ?>
        </textarea><br><br>

        <button type="submit">Save Booking</button>
        <a href="booking_manager.php" class="button">Cancel</a>
<button type="submit" name="delete" value="1" onclick="return confirm('Are you sure you want to delete this booking? This cannot be undone.');">Delete Booking</button>

    </form>
</div>
<script>
  document.addEventListener('DOMContentLoaded', () => {
    tinymce.init({
      selector: '#preview_intro, #preview_conclusion',
      height: 300,
      plugins: [
        'advlist', 'autolink', 'lists', 'link', 'image', 'charmap', 'preview',
        'anchor', 'searchreplace', 'visualblocks', 'code', 'fullscreen',
        'insertdatetime', 'media', 'table', 'code', 'help', 'wordcount', 'emoticons', 'hr'
      ],
      toolbar: [
        'undo redo | blocks | bold italic underline strikethrough removeformat | ' +
        'alignleft aligncenter alignright alignjustify | ' +
        'bullist numlist outdent indent | link media table hr emoticons charmap | ' +
        'code fullscreen preview help'
      ],
      branding: false,
license_key: 'gpl'
    });
  });
</script>
</body>
</html>