<?php

error_reporting(E_ALL);
ini_set('display_errors', 1);

require_once 'auth.php';
requireLogin();
$user = currentUser();
$groupId = (int)($user['group_id'] ?? 0);
if ($groupId < 9) {
    die("Unauthorized");
}
require_once '../config/db.php';

$categoryQuery = $db->query("SELECT name FROM event_categories ORDER BY name ASC");
$availableCategories = [];
while ($row = $categoryQuery->fetch_assoc()) {
    $availableCategories[] = $row['name'];
}


if (!isset($_GET['id']) || !is_numeric($_GET['id'])) {
    header("Location: event_manager.php");
    exit;
}

$id = (int)$_GET['id'];
$stmt = $db->prepare("SELECT * FROM events WHERE id = ? AND is_deleted = 0");
$stmt->bind_param("i", $id);
$stmt->execute();
$result = $stmt->get_result();
$event = $result->fetch_assoc();

if (!$event) {
    echo "<p class='notice error'>Event not found.</p>";
    exit;
}

$message = '';

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    if (isset($_POST['delete'])) {
        $delStmt = $db->prepare("UPDATE events SET is_deleted = 1 WHERE id = ?");
        $delStmt->bind_param("i", $id);
        $delStmt->execute();
        header("Location: event_manager.php");
        exit;
    }

    $name = trim($_POST['name']);
    $short_name = trim($_POST['short_name']);
    $event_type = $_POST['event_type'];
    $selectedCategories = $_POST['categories'] ?? ['NONE'];
    $categoryString = implode(',', array_map('trim', $selectedCategories));

    $image_path = $event['image_path'];
    if (!empty($_FILES['image']['name'])) {
        $targetDir = '../uploads/show-logos/';
        $filename = basename($_FILES['image']['name']);
        $targetFile = $targetDir . time() . "_" . $filename;

        if (move_uploaded_file($_FILES['image']['tmp_name'], $targetFile)) {
            $image_path = basename($targetFile);
        }
    }

    if ($name && $event_type) {
        $updateStmt = $db->prepare("UPDATE events SET name = ?, short_name = ?, event_type = ?, image_path = ?, categories = ? WHERE id = ?");
        $updateStmt->bind_param("sssssi", $name, $short_name, $event_type, $image_path, $categoryString, $id);
        $updateStmt->execute();
 header("Location: event_manager.php");
        $message = "<p class='notice success'>Event updated successfully.</p>";
    } else {
        $message = "<p class='notice error'>Please fill out all required fields.</p>";
    }
}
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <title>Edit Event</title>
    <link rel="stylesheet" href="css/admin.css">
</head>
<body>
    <div class="dashboard-wrapper">
        <h2>Edit Event</h2>
        <?php echo $message; ?>
        <form method="post" enctype="multipart/form-data">
            <b><label>Event Name:</b><br><input type="text" name="name" value="<?php echo htmlspecialchars($event['name']); ?>" required></label><br><br>
           <b><label>Short Name:</b><br><input type="text" name="short_name" value="<?php echo htmlspecialchars($event['short_name']); ?>"></label><br><br>
            <b><label>Event Type:</b><br>
                <select name="event_type" required>
                    <option value="">Select Type</option>
                    <option value="Non Aired/Streamed" <?php if ($event['event_type'] == 'Non Aired/Streamed') echo 'selected'; ?>>Non Aired/Streamed</option>
                    <option value="On Air/Streaming/Flagship Shows" <?php if ($event['event_type'] == 'On Air/Streaming/Flagship Shows') echo 'selected'; ?>>On Air/Streaming/Flagship Shows</option>
                    <option value="PPV/PLE Events" <?php if ($event['event_type'] == 'PPV/PLE Events') echo 'selected'; ?>>PPV/PLE Events</option>
                    <option value="Special Events" <?php if ($event['event_type'] == 'Special Events') echo 'selected'; ?>>Special Events</option>
                </select>
            </label><br><br>
    <b><label for="categories">Event Categories:</label></b><br>
    <select name="categories[]" id="categories" multiple size="6">
        <option value="NONE">None</option>
        <?php foreach ($availableCategories as $cat): ?>
            <option value="<?= htmlspecialchars($cat) ?>" <?= in_array($cat, explode(',', $event['categories'] ?? 'NONE')) ? 'selected' : '' ?>>
                <?= htmlspecialchars($cat) ?>
            </option>
        <?php endforeach; ?>
    </select>
<br><br>
            <?php if (!empty($event['image_path']) && file_exists("../uploads/show-logos/{$event['image_path']}")): ?>
                <p><b>Current Image:</b><br><img src="../uploads/show-logos/<?php echo $event['image_path']; ?>" style="max-height: 100px;"></p>
            <?php endif; ?>
            <b><label>Change Image:</b> <small style="color:gray;">Recommended size 300x150 or similar.</small><br><input type="file" name="image" accept="image/*"></label><br><br>
            <button type="submit" class="button">Update Event</button>
            <button type="submit" name="delete" class="button danger" onclick="return confirm('Are you sure you want to delete this event?')">Delete Event</button>
<a href="event_manager.php" class="button">Back to Event Manager</a>
        

</form>
      
    </div>
</body>
</html>
