<?php
ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);

require_once 'auth.php';
requireLogin();
$user = currentUser();
$groupId = (int)($user['group_id'] ?? 0);
if ($groupId < 9) {
    die("Unauthorized");
}
require_once '../config/db.php';

$message = '';

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // Delete logic
    if (isset($_POST['delete_id'])) {
        $id = (int)$_POST['delete_id'];
        $stmt = $db->prepare("UPDATE event_categories SET is_deleted = 1 WHERE id = ?");
        $stmt->bind_param("i", $id);
        $stmt->execute();
        $message = "<p class='notice success'>Category deleted.</p>";
    }

    // Edit logic
    elseif (isset($_POST['edit_id'], $_POST['edit_name'])) {
        $id = (int)$_POST['edit_id'];
        $name = trim($_POST['edit_name']);
        $imagePath = null;

        if (!empty($_FILES['edit_image']['name'])) {
            $targetDir = '../uploads/category-logos/';
            if (!is_dir($targetDir)) mkdir($targetDir, 0777, true);
            $filename = time() . "_" . basename($_FILES['edit_image']['name']);
            $targetFile = $targetDir . $filename;

            if (move_uploaded_file($_FILES['edit_image']['tmp_name'], $targetFile)) {
                $imagePath = $filename;
            }
        }

        if ($imagePath) {
            $stmt = $db->prepare("UPDATE event_categories SET name = ?, image_path = ? WHERE id = ?");
            $stmt->bind_param("ssi", $name, $imagePath, $id);
        } else {
            $stmt = $db->prepare("UPDATE event_categories SET name = ? WHERE id = ?");
            $stmt->bind_param("si", $name, $id);
        }

        $stmt->execute();
        $message = "<p class='notice success'>Category updated.</p>";
    }

    // Add logic
    elseif (!empty($_POST['add_name'])) {
        $name = trim($_POST['add_name']);
        $imagePath = null;

        if (!empty($_FILES['add_image']['name'])) {
            $targetDir = '../uploads/category-logos/';
            if (!is_dir($targetDir)) mkdir($targetDir, 0777, true);
            $filename = time() . "_" . basename($_FILES['add_image']['name']);
            $targetFile = $targetDir . $filename;

            if (move_uploaded_file($_FILES['add_image']['tmp_name'], $targetFile)) {
                $imagePath = $filename;
            }
        }

        $stmt = $db->prepare("INSERT INTO event_categories (name, image_path) VALUES (?, ?)");
        $stmt->bind_param("ss", $name, $imagePath);
        $stmt->execute();
        $message = "<p class='notice success'>Category added.</p>";
    }
}

$categories = $db->query("SELECT * FROM event_categories WHERE is_deleted = 0 ORDER BY id ASC")->fetch_all(MYSQLI_ASSOC);
?>

<!DOCTYPE html>
<html>
<head>
    <meta charset="UTF-8">
    <title>Event Categories</title>
    <link rel="stylesheet" href="css/admin.css">
</head>
<body>
<div class="dashboard-wrapper">
    <h2>Event Type Manager</h2>
    <?= $message ?>

    <form method="post" enctype="multipart/form-data" style="border:2px dashed #007bff;padding:10px;margin-bottom:20px;">
        <input type="text" name="add_name" placeholder="Enter new category name" required>
        <label>Upload Image:</label>
        <input type="file" name="add_image" accept="image/*">
        <button type="submit" class="button">Add New</button>
    </form>

    <?php foreach ($categories as $row): ?>
        <form method="post" enctype="multipart/form-data" style="display:flex; align-items:center; gap:10px; margin-bottom:15px; padding:10px; border:1px solid #ccc;">
    <input type="hidden" name="edit_id" value="<?= $row['id'] ?>">
    <input type="text" name="edit_name" value="<?= htmlspecialchars($row['name']) ?>" required>
    <?php if (!empty($row['image_path'])): ?>
        <img src="../uploads/category-logos/<?= htmlspecialchars($row['image_path']) ?>" alt="Logo" style="height:30px;">
    <?php endif; ?>
    <input type="file" name="edit_image" accept="image/*">
    <button type="submit" class="button">Edit</button>

    <button type="submit" name="delete_id" value="<?= $row['id'] ?>" class="button danger"
        onclick="return confirm('Are you sure you want to delete this category?');">Delete</button>
</form>

        <div style="clear:both;"></div>
    <?php endforeach; ?>
</div>
</body>
</html>
