<?php

error_reporting(E_ALL);
ini_set('display_errors', 1);

require_once 'auth.php';
requireLogin();
$user = currentUser();
$groupId = (int)($user['group_id'] ?? 0);
if ($groupId < 9) {
    die("Unauthorized");
}
require_once '../config/db.php';

$eventTypes = [
    'Non Aired/Streamed' => 'Non-Aired / House Show',
    'On Air/Streaming/Flagship Shows' => 'On-Air / Weekly TV',
    'PPV/PLE Events' => 'PPV / PLE',
    'Special Events' => 'Special Event'
];

$eventsByType = [];

// Fetch events for each type
foreach ($eventTypes as $eventTypeKey => $label) {
    $stmt = $db->prepare("SELECT * FROM events WHERE event_type = ? AND is_deleted = 0 ORDER BY sort_order ASC");
    $stmt->bind_param("s", $eventTypeKey);
    $stmt->execute();
    $result = $stmt->get_result();
    $eventsByType[$eventTypeKey] = $result->fetch_all(MYSQLI_ASSOC);
}
?>

<!DOCTYPE html>
<html>
<head>
    <title>Event Manager</title>
    <link rel="stylesheet" href="css/admin.css">
    <link rel="stylesheet" href="css/event-manager.css">
<script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
<script src="https://code.jquery.com/ui/1.13.2/jquery-ui.min.js"></script>

</head>
<body>
<div class="dashboard-wrapper">
    <h2>Event Manager</h2>

    <div class="event-columns">
        <?php foreach ($eventTypes as $typeId => $label): ?>
            <div class="event-column">
                <h2><?= htmlspecialchars($label) ?></h2>

                <?php if (!empty($eventsByType[$typeId])): ?>
                    <ul class="sortable" data-type="<?= $typeId ?>">
                        <?php foreach ($eventsByType[$typeId] as $event): ?>
                            <li class="event-row" data-id="<?= $event['id'] ?>">
                                <?php if (!empty($event['image_path'])): ?>
    <img src="../../uploads/show-logos/<?= htmlspecialchars($event['image_path']) ?>" class="thumb" alt="Logo">
<?php endif; ?>

                           
<strong><?= htmlspecialchars($event['name']) ?></strong>
<em><?= htmlspecialchars($event['short_name']) ?></em>
<?php if (!empty($event['categories']) && $event['categories'] !== 'NONE'): ?>
    <div class="event-category"><small><?= htmlspecialchars($event['categories']) ?></small></div>
<?php endif; ?>


                                <a href="edit_event.php?id=<?= $event['id'] ?>" class="button small">Edit</a>
                                <button class="arrow-up" data-id="<?= $event['id'] ?>">↑</button>
                                <button class="arrow-down" data-id="<?= $event['id'] ?>">↓</button>
                            </li>
                        <?php endforeach; ?>
                    </ul>
                <?php else: ?>
                    <div class="no-events">No events in this category.</div>
                <?php endif; ?>
            </div>
        <?php endforeach; ?>
    </div>

    <br><P><center><a href="add_event.php" class="btn">Add New Event</a>    <a href="event_categories.php" class="btn">Categories</a></center><br><p>

</div>
<script src="event_sort.js"></script>


<!-- Include jQuery, jQuery UI, and event_sort.js -->
<script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
<script src="https://code.jquery.com/ui/1.13.2/jquery-ui.min.js"></script>
<script src="event_sort.js"></script>

</body>
</html>
