<?php
require_once '../config/db.php';
require_once 'auth.php';
requireLogin();
$user = currentUser();
if ($user['group_id'] < 9) {
    echo "<p>You do not have access to this page.</p>";
    exit;
}

// Get selected week from dropdown
$selectedWeek = isset($_GET['week']) ? $_GET['week'] : date('Y-m-d', strtotime('monday this week'));
$weekStart = $selectedWeek;
$weekEnd = date('Y-m-d', strtotime($weekStart . ' +6 days'));

// CSV Export
if (isset($_GET['export']) && $_GET['export'] === '1') {
    header('Content-Type: text/csv');
    header('Content-Disposition: attachment; filename="match_breakdown_' . $weekStart . '.csv"');

    $output = fopen('php://output', 'w');
    fputcsv($output, ['Match Name', 'Air Date', 'Match Type', 'Character', 'Result', 'Points']);

    $legend = [];
    $res = $db->query("SELECT match_type_id, win_points, loss_points, draw_points FROM power_point_legend");
    while ($row = $res->fetch_assoc()) {
        $legend[$row['match_type_id']] = $row;
    }

    $query = "
        SELECT em.id AS match_id, em.match_name, em.match_type_id, mt.name AS type_name,
               eb.label, eb.air_date
        FROM event_matches em
        JOIN event_bookings eb ON em.booking_id = eb.id
        LEFT JOIN match_types mt ON em.match_type_id = mt.id
        WHERE LOWER(eb.booking_status) = 'public'
          AND eb.air_date BETWEEN '{$weekStart}' AND '{$weekEnd}'
          AND em.is_segment = 0
        ORDER BY eb.air_date ASC, em.id ASC
    ";
    $matches = $db->query($query)->fetch_all(MYSQLI_ASSOC);

    $results = [];
    $res = $db->query("
        SELECT mr.match_id, mr.character_id, mr.result, c.name
        FROM match_results mr
        JOIN characters c ON mr.character_id = c.id
    ");
    while ($row = $res->fetch_assoc()) {
        $results[$row['match_id']][] = $row;
    }

    foreach ($matches as $match) {
        foreach ($results[$match['match_id']] ?? [] as $res) {
            $pts = 0;
            $outcome = strtolower($res['result']);
            if (isset($legend[$match['match_type_id']])) {
                if ($outcome === 'win') $pts = $legend[$match['match_type_id']]['win_points'];
                elseif ($outcome === 'loss') $pts = $legend[$match['match_type_id']]['loss_points'];
                elseif ($outcome === 'nc') $pts = $legend[$match['match_type_id']]['draw_points'];
            }
            fputcsv($output, [$match['match_name'], $match['air_date'], $match['type_name'], $res['name'], strtoupper($res['result']), $pts]);
        }
    }

    fclose($output);
    exit;
}

// Get available weeks from event_bookings
$weeks = $db->query("SELECT DISTINCT DATE_FORMAT(air_date, '%Y-%m-%d') as week_start FROM event_bookings WHERE booking_status = 'Public' ORDER BY air_date DESC");
?>

<!DOCTYPE html>
<html>
<head>
    <title>Power Rankings Match Breakdown</title>
    <link rel="stylesheet" href="css/admin.css">
    <style>
        .win { color: green; }
        .loss { color: red; }
        .nc { color: gray; }
    </style>
</head>
<body>
<div class="dashboard-wrapper">
    <h1>Match Breakdown: Week of <?= htmlspecialchars($weekStart) ?></h1>

    <form method="get" style="margin-bottom: 1em;">
        <label for="week">Select Week:</label>
        <select name="week" id="week" onchange="this.form.submit()">
            <?php while ($row = $weeks->fetch_assoc()):
                $w = $row['week_start'];
                $selected = ($w === $weekStart) ? 'selected' : '';
            ?>
                <option value="<?= $w ?>" <?= $selected ?>><?= $w ?></option>
            <?php endwhile; ?>
        </select>
        <button type="submit">View</button>
        <a class="admin-button" href="?week=<?= $weekStart ?>&export=1" style="margin-left: 10px;">Export CSV</a>
    </form>

<?php
// Repeat match display block (simplified from earlier version)
$legend = [];
$res = $db->query("SELECT match_type_id, win_points, loss_points, draw_points FROM power_point_legend");
while ($row = $res->fetch_assoc()) {
    $legend[$row['match_type_id']] = $row;
}

$query = "
    SELECT em.id AS match_id, em.match_name, em.match_type_id, mt.name AS type_name,
           eb.label, eb.air_date
    FROM event_matches em
    JOIN event_bookings eb ON em.booking_id = eb.id
    LEFT JOIN match_types mt ON em.match_type_id = mt.id
    WHERE LOWER(eb.booking_status) = 'public'
      AND eb.air_date BETWEEN '{$weekStart}' AND '{$weekEnd}'
      AND em.is_segment = 0
    ORDER BY eb.air_date ASC, em.id ASC
";
$matches = $db->query($query)->fetch_all(MYSQLI_ASSOC);

$results = [];
$res = $db->query("
    SELECT mr.match_id, mr.character_id, mr.result, c.name
    FROM match_results mr
    JOIN characters c ON mr.character_id = c.id
");
while ($row = $res->fetch_assoc()) {
    $results[$row['match_id']][] = $row;
}
?>

<?php if (empty($matches)): ?>
    <p>No matches found for this week.</p>
<?php endif; ?>

<?php foreach ($matches as $match): ?>
    <div style="margin-bottom: 2em;">
        <h3><?= htmlspecialchars($match['match_name']) ?> (<?= htmlspecialchars($match['label']) ?> — <?= $match['air_date'] ?>)</h3>
        <p><strong>Type:</strong> <?= htmlspecialchars($match['type_name'] ?? 'Unknown') ?></p>
        <table class="admin-table">
            <thead>
                <tr>
                    <th>Character</th>
                    <th>Result</th>
                    <th>Points Earned</th>
                </tr>
            </thead>
            <tbody>
                <?php foreach ($results[$match['match_id']] ?? [] as $res): ?>
                    <?php
                        $pts = 0;
                        $outcome = strtolower($res['result']);
                        if (isset($legend[$match['match_type_id']])) {
                            if ($outcome === 'win') $pts = $legend[$match['match_type_id']]['win_points'];
                            elseif ($outcome === 'loss') $pts = $legend[$match['match_type_id']]['loss_points'];
                            elseif ($outcome === 'nc') $pts = $legend[$match['match_type_id']]['draw_points'];
                        }
                    ?>
                    <tr>
                        <td><?= htmlspecialchars($res['name']) ?></td>
                        <td class="<?= $outcome ?>"><?= strtoupper($outcome) ?></td>
                        <td><?= number_format($pts, 2) ?></td>
                    </tr>
                <?php endforeach; ?>
            </tbody>
        </table>
    </div>
<?php endforeach; ?>

<div style="margin: 2em 0;">
    <a href="power_rankings_dashboard.php" class="admin-button">← Return to Power Rankings Dashboard</a>
</div>

</div>
</body>
</html>
