<?php
require_once '../config/db.php';
require_once 'auth.php';
requireLogin();
$user = currentUser();
if ($user['group_id'] < 9) {
    echo "<p>You do not have access to this page.</p>";
    exit;
}

require_once 'libs/functions.php';

$weekStart = date('Y-m-d', strtotime('monday this week'));

// Get snapshot for the current week
$stmt = $db->prepare("SELECT id FROM power_ranking_snapshots WHERE week_start = ?");
$stmt->bind_param("s", $weekStart);
$stmt->execute();
$result = $stmt->get_result();
$snapshot = $result->fetch_assoc();
$snapshotId = $snapshot['id'] ?? null;

if (!$snapshotId) {
    echo "<p>No power ranking data found for this week.</p>";
    exit;
}

// Calculate year start based on this week’s year
$yearStart = date('Y-01-01', strtotime($weekStart));

// Fetch running totals and prior totals for all characters in this year
$query = "
    SELECT
      c.id,
      c.name,
      SUM(
        CASE
          WHEN s.week_start >= ? AND s.week_start <= ?
          THEN prs.total_points ELSE 0
        END
      ) AS current_total,
      SUM(
        CASE
          WHEN s.week_start >= ? AND s.week_start < ?
          THEN prs.total_points ELSE 0
        END
      ) AS previous_total
    FROM power_ranking_scores prs
    JOIN power_ranking_snapshots s ON s.id = prs.snapshot_id
    JOIN characters c ON c.id = prs.character_id
    GROUP BY c.id, c.name
    ORDER BY current_total DESC
";
$stmt = $db->prepare($query);
$stmt->bind_param("ssss", $yearStart, $weekStart, $yearStart, $weekStart);
$stmt->execute();
$res = $stmt->get_result();
$rankings = $res->fetch_all(MYSQLI_ASSOC);

// Compute movement and normalize into total_points for display
foreach ($rankings as &$entry) {
    $entry['total_points'] = $entry['current_total'];
    if ($entry['current_total'] > $entry['previous_total']) {
        $entry['movement'] = 'up';
    } elseif ($entry['current_total'] < $entry['previous_total']) {
        $entry['movement'] = 'down';
    } else {
        $entry['movement'] = 'same';
    }
}
unset($entry);
?>

<!DOCTYPE html>
<html>
<head>
    <title>Power Rankings</title>
    <link rel="stylesheet" href="css/admin.css">
    <style>
        .movement-up   { color: green; font-weight: bold; }
        .movement-down { color: red;   font-weight: bold; }
        .movement-same { color: gray;  font-weight: bold; }
    </style>
</head>
<body>
<div class="dashboard-wrapper">
    <h1>Power Rankings (Week of <?= htmlspecialchars($weekStart) ?>)</h1>
    <table class="admin-table">
        <thead>
            <tr>
                <th>Rank</th>
                <th>Character</th>
                <th>Points</th>
                <th>Movement</th>
            </tr>
        </thead>
        <tbody>
            <?php
            $rank = 1;
            foreach ($rankings as $entry):
                $movementClass = 'movement-' . $entry['movement'];
                $symbol = match($entry['movement']) {
                    'up'   => '▲',
                    'down' => '▼',
                    default=> '＝',
                };
            ?>
            <tr>
                <td><?= $rank++ ?></td>
                <td><?= htmlspecialchars($entry['name']) ?></td>
                <td><?= number_format($entry['total_points'], 2) ?></td>
                <td class="<?= $movementClass ?>"><?= $symbol ?></td>
            </tr>
            <?php endforeach; ?>
        </tbody>
    </table>
    <div style="margin: 2em 0;">
        <a href="power_rankings_dashboard.php" class="admin-button">← Return to Power Rankings Dashboard</a>
    </div>
</div>
</body>
</html>
