<?php
// -------------------------------------------------
// welcome.php (updated to route “Submit” to submit_match.php and show “Submitted” + “Edit” when match_content exists)
// -------------------------------------------------
ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);

require_once '../config/db.php';
require_once __DIR__ . '/auth.php';
requireLogin();

$user     = currentUser();
$user_id  = (int)$user['id'];
$group_id = (int)$user['group_id'];
$isAdmin  = ($group_id == 9 || $group_id == 10);

  function versionCompare($local, $remote) {
    return version_compare(trim($local), trim($remote), '<');
}

// -------------------------------------
// Version Check Notification (Admins/Webmasters)
// -------------------------------------
if ($isAdmin) {
    $localVersion = '0.0.0';
   $result = $db->query("SELECT setting_value FROM site_settings WHERE setting_key = 'ems_local_version' LIMIT 1");

    if ($result && $row = $result->fetch_assoc()) {
        $localVersion = $row['setting_value'];
    }

    $latestVersion = $localVersion;
    if (!isset($_SESSION['suppress_update_notice'])) {
        $ch = curl_init('https://efedmanagementsuite.com/version.php');
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($ch, CURLOPT_TIMEOUT, 2);
        $response = curl_exec($ch);
        curl_close($ch);

        if ($response) {
            $data = json_decode($response, true);
            if (!empty($data['version'])) {
                $latestVersion = $data['version'];
            }
        }
    }
// Only for Admins (9) and Webmasters (10)
$user = currentUser();               // however you fetch
$groupId = (int)($user['group_id'] ?? 0);
if ($groupId >= 9) {
    // pull the saved key
    $licenseKey = getSetting('license_key') ?? '';

    // if empty → show persistent alert
    if ($licenseKey === '') {
        echo "
        ";
    } else {
        // optionally re-validate on each load:
        $localVersion = getSetting('ems_local_version') ?? '0';
$url = 'https://dashboard.efedmanagementsuite.com/download_dashboard/api/validate_license.php'
     . '?key='     . urlencode($licenseKey)
     . '&version=' . urlencode($localVersion);

        $resp = @file_get_contents($url);
        $ok   = ($resp && json_decode($resp, true)['valid'] ?? false);
        if (!$ok) {
            echo "
            ";
        }
    }
}
 

}

// 1) Fetch all upcoming “Booking” events
$stmt = $db->prepare("
    SELECT 
        eb.id, 
        eb.label, 
        eb.air_date, 
        eb.booking_status, 
        e.name AS event_name
    FROM event_bookings eb
    JOIN events e ON eb.event_id = e.id
    WHERE eb.booking_status = 'Booking' 
      AND eb.is_deleted = 0
    ORDER BY eb.air_date ASC
");
$stmt->execute();
$result = $stmt->get_result();
$events = $result->fetch_all(MYSQLI_ASSOC);
$stmt->close();
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <title>Welcome Dashboard</title>
    <link rel="stylesheet" href="css/admin.css">
    <style>
        .button.locked {
            background-color: #ccc;
            color: #666;
            cursor: not-allowed;
            pointer-events: none;
        }
        .button.small.disabled {
            background-color: #999;
            color: #fff;
            cursor: default;
        }
        .update-notice {
            background-color: #ffeeba;
            border: 1px solid #f5c6cb;
            color: #856404;
            padding: 15px;
            margin-bottom: 20px;
            border-radius: 6px;
            display: flex;
            justify-content: space-between;
            align-items: center;
        }
        .update-notice button {
            background: none;
            border: none;
            font-weight: bold;
            cursor: pointer;
            color: #856404;
        }

        @media (max-width: 768px) {
            .dashboard-wrapper .button,
            .dashboard-wrapper .btn {
                display: block;
                width: calc(90% - 20px);
                margin: 10px auto 0 auto;
            }

            .dashboard-wrapper .match-row,
            .dashboard-wrapper .segment-row {
                flex-direction: column !important;
                align-items: stretch !important;
            }

            .dashboard-wrapper .button.small {
                font-size: 14px;
            }
        }

  /* License Alert Styles */
  .license-alert {
    background: #ff4757;               /* bright red */
    color: #fff;
    padding: 12px 16px;
    margin: 16px;
    border-radius: 6px;
    display: flex;
    align-items: center;
    font-size: 1rem;
    font-weight: 600;
    box-shadow: 0 4px 8px rgba(0,0,0,0.2);
    animation: pulse 2s infinite;
  }

  .license-alert svg {
    flex-shrink: 0;
    width: 24px;
    height: 24px;
    margin-right: 12px;
    animation: shake 1.5s infinite;
  }

  @keyframes pulse {
    0%, 100% { transform: scale(1); }
    50%      { transform: scale(1.02); }
  }

  @keyframes shake {
    0%, 100% { transform: translateX(0); }
    25%      { transform: translateX(-2px); }
    75%      { transform: translateX(2px); }
  }


    </style>
</head>
<body>
<div class="dashboard-wrapper">
    <?php if ($isAdmin && versionCompare($localVersion, $latestVersion) && !isset($_SESSION['suppress_update_notice'])): ?>
        <div class="update-notice">
            <div>
                ⚠️ <strong>Update Available:</strong> A new version of the eFed Management Suite is available (v<?= htmlspecialchars($latestVersion) ?>). 
                Visit <a href="https://efedmanagementsuite.com" target="_blank">efedmanagementsuite.com</a> to download.
            </div>
            <button onclick="fetch('suppress_update_notice.php').then(() => this.parentElement.style.display='none');">Dismiss ✕</button>
        </div>
    <?php endif; ?>
<?php if ($group_id >= 9): ?>
  <?php if ($licenseKey === ''): ?>
    <div class="license-alert">
      <!-- Inline SVG “!” icon -->
      <svg viewBox="0 0 24 24" fill="currentColor" xmlns="http://www.w3.org/2000/svg">
        <path d="M11 7h2v6h-2V7zm0 8h2v2h-2v-2z"/>
        <path fill-rule="evenodd" clip-rule="evenodd"
              d="M12 2C6.477 2 2 6.477 2 12s4.477 10 10 10
                 10-4.477 10-10S17.523 2 12 2zm0 18c-4.411 0-8-3.589-8-8
                 s3.589-8 8-8 8 3.589 8 8-3.589 8-8 8z"/>
      </svg>
      <div>
        <strong>No license key found.</strong><br>
        Please <a href="https://efedmanagementsuite.com" target="_blank" style="color:#ffd700;text-decoration:underline;">
          get your free license key
        </a> before continuing.
      </div>
    </div>
  <?php elseif (!$ok): ?>
    <div class="license-alert">
      <svg viewBox="0 0 24 24" fill="currentColor" xmlns="http://www.w3.org/2000/svg">
        <!-- same SVG -->
      </svg>
      <div>
        <strong>Invalid license key.</strong><br>
        Visit <a href="https://efedmanagementsuite.com" target="_blank" style="color:#ffd700;text-decoration:underline;">
          eMS Dashboard
        </a> to retrieve a valid one.
      </div>
    </div>
  <?php endif; ?>
<?php endif; ?>

    <h2 class="dashboard-section-title">Upcoming Events</h2>

    <?php if (empty($events)): ?>
        <p>No events currently in booking status.</p>
    <?php else: ?>
        <?php foreach ($events as $event): ?>
            <div class="dashboard-box">
                <h3>
                    <?= htmlspecialchars($event['event_name']) ?>:
                    <?= htmlspecialchars($event['label']) ?> -
                    <?= date('M d, Y', strtotime($event['air_date'])) ?>
                    (<?= htmlspecialchars($event['booking_status']) ?>)
                </h3>

                <div class="button-row" align="center">
                    <?php if ($group_id >= 3): ?>
                        <a href="reserve_segment.php?booking_id=<?= $event['id'] ?>" class="button">Reserve Segment</a>
                        <a href="submit_promo.php?booking_id=<?= $event['id'] ?>" class="button">Submit Promo</a>
                    <?php else: ?>
                        <span class="button locked" title="Available to Handlers and above">&#x1f512; Reserve Segment</span>
                        <span class="button locked" title="Available to Handlers and above">&#x1f512; Submit Promo</span>
                    <?php endif; ?>

                    <?php if ($isAdmin): ?>
                        <a href="manage_card.php?booking_id=<?= $event['id'] ?>" class="button">Edit / Reorder Lineup</a>
                        <a href="results_compiler_edit.php?booking_id=<?= $event['id'] ?>" class="button">Manage Results</a>
                    <?php else: ?>
                        <span class="button locked">&#x1f512; Edit / Reorder Lineup</span>
                        <span class="button locked">&#x1f512; Manage Results</span>
                    <?php endif; ?>
                </div>

                <table class="table">
                    <thead>
                        <tr>
                            <th>Match / Segment</th>
                            <th>Lead Writer(s)</th>
                            <th>Submit</th>
                        </tr>
                    </thead>
                    <tbody>
                    <?php
                    $stmt2 = $db->prepare("
                        SELECT id, match_name, is_segment, match_content, status
                        FROM event_matches 
                        WHERE booking_id = ? 
                        ORDER BY sort_order ASC
                    ");
                    $stmt2->bind_param("i", $event['id']);
                    $stmt2->execute();
                    $matches = $stmt2->get_result();
                    while ($match = $matches->fetch_assoc()):
                        $matchId = $match['id'];
                        $writers = [];

                        if ($match['is_segment']) {
                            $writersStmt = $db->prepare("
                                SELECT u.handler_name
                                FROM event_matches em
                                JOIN reserved_segments rs ON em.reserved_segment_id = rs.id
                                JOIN segment_credits sc ON rs.id = sc.segment_id
                                JOIN users u ON sc.user_id = u.id
                                WHERE em.id = ?
                            ");
                        } else {
                            $writersStmt = $db->prepare("
                                SELECT u.handler_name
                                FROM event_match_writers mw
                                JOIN users u ON mw.user_id = u.id
                                WHERE mw.match_id = ?
                            ");
                        }

                        $writersStmt->bind_param("i", $matchId);
                        $writersStmt->execute();
                        $writersResult = $writersStmt->get_result();
                        while ($writer = $writersResult->fetch_assoc()) {
                            $writers[] = htmlspecialchars($writer['handler_name']);
                        }
                        $writersStmt->close();

                        $hasAccess = false;
                        if ($isAdmin) {
                            $hasAccess = true;
                        } else {
                            if ($match['is_segment']) {
                                $checkStmt = $db->prepare("
                                    SELECT 1 
                                    FROM event_matches em
                                    JOIN reserved_segments rs ON em.reserved_segment_id = rs.id
                                    JOIN segment_credits sc ON rs.id = sc.segment_id
                                    WHERE em.id = ? AND sc.user_id = ?
                                ");
                            } else {
                                $checkStmt = $db->prepare("
                                    SELECT 1 
                                    FROM event_match_writers 
                                    WHERE match_id = ? AND user_id = ?
                                ");
                            }
                            $checkStmt->bind_param("ii", $matchId, $user_id);
                            $checkStmt->execute();
                            $hasAccess = $checkStmt->get_result()->num_rows > 0;
                            $checkStmt->close();
                        }
                    ?>
                        <tr>
                            <td><strong><?= htmlspecialchars($match['match_name']) ?></strong></td>
                            <td><?= implode(", ", $writers) ?></td>
                            <td>
                                <?php
                                    if (!$hasAccess) {
                                        echo '<span class="button small locked">Locked</span>';
                                    } else {
                                        $url = $match['is_segment']
                                            ? "submit_reserved_segment.php?match_id=$matchId"
                                            : "submit_match.php?match_id=$matchId";

                                        if ($match['status'] === 'submitted') {
                                            echo '<span class="button small disabled">Submitted</span> ';
                                            echo '<a href="' . $url . '" class="button small">Edit</a>';
                                        } else {
                                            echo '<a href="' . $url . '" class="button small">Submit</a>';
                                        }
                                    }
                                ?>
                            </td>
                        </tr>
                    <?php endwhile; ?>
                    <?php $stmt2->close(); ?>
                    </tbody>
                </table>
            </div><br><hr><p>
        <?php endforeach; ?>
    <?php endif; ?>
</div><br><p><br><p><br><p><br>
</body>
</html>