<?php
// Detect uninstalled state
$installPath = __DIR__ . '/install.php';
$dbConfigPath = __DIR__ . '/config/db.php';

if (file_exists($installPath) && (!file_exists($dbConfigPath) || filesize($dbConfigPath) === 0)) {
    echo "<div style='background:#ffdddd; padding:15px; border:1px solid #cc0000; font-family:sans-serif; color:#900;'>
        <strong>Installation Not Completed:</strong> You must run <code>install.php</code> to complete setup.<br>
        <a href='install.php'>Click here to begin installation</a>
    </div>";
    exit;
}

require_once __DIR__ . '/admin/auth.php';
require_once __DIR__ . '/config/db.php';



// Default to home if no page is set
if (!isset($_GET['page'])) {
    $_GET['page'] = 'home';
}

if ($_GET['page'] === 'view_events_by_category') {
    include 'user_content/view_events-by-category.php';
    exit;
}


// Get the requested page and optional slug
$page = $_GET['page'] ?? 'home';
$slug = $_GET['slug'] ?? null;

// Sanitize input
$page = preg_replace('/[^a-zA-Z0-9_-]/', '', $page);
$slug = $slug ? preg_replace('/[^a-zA-Z0-9_-]/', '', $slug) : null;

// Default template fallback
$template = 'default';

// Fetch template name from DB
$stmt = $db->prepare("SELECT template_name FROM content_page_templates WHERE slug = ? AND deleted = 0 LIMIT 1");
$stmt->bind_param("s", $page);
$stmt->execute();
$stmt->bind_result($dbTemplate);
if ($stmt->fetch()) {
    $template = $dbTemplate;
}
$stmt->close();

// File paths
$contentFile = __DIR__ . "/user_content/$page.php";
$headerFile  = __DIR__ . "/templates/$template/header.php";
$footerFile  = __DIR__ . "/templates/$template/footer.php";

// Load header
if (file_exists($headerFile)) {
    include $headerFile;
} else {
    echo "<p><strong>Header file missing:</strong> $headerFile</p>";
}

// Load main content
if (file_exists($contentFile)) {
    include $contentFile;
} else {
    echo "<p><strong>Page not found:</strong> $page</p>";
}

// Load footer
if (file_exists($footerFile)) {
    include $footerFile;
} else {
    echo "<p><strong>Footer file missing:</strong> $footerFile</p>";
}