<?php

require_once 'config/db.php';  // safe now

// Toggle: 'all' or 'category'
$view_mode = 'category'; // Change to 'all' to restore original layout

$categories = $db->query("
    SELECT ec.id, ec.name, ec.image_path
    FROM event_categories ec
    WHERE ec.is_deleted = 0
      AND EXISTS (
          SELECT 1 FROM events e
          INNER JOIN event_bookings eb ON eb.event_id = e.id
          WHERE FIND_IN_SET(ec.name, e.categories)
            AND eb.booking_status = 'Public'
            AND eb.is_deleted = 0
      )
    ORDER BY ec.name ASC
")->fetch_all(MYSQLI_ASSOC);

// --- Fetch recent results ---
function fetchRecentPublicEvents($db) {
    $sql = "
        SELECT 
            eb.id AS event_booking_id,
            e.name AS show_name,
            eb.label AS event_label,
            eb.air_date AS air_date,
            COALESCE(NULLIF(eb.custom_image_path, ''), e.image_path) AS logo_file,
            v.name AS venue_name,
            v.location AS venue_location,
            c.name AS country_name
        FROM event_bookings eb
        INNER JOIN events e ON eb.event_id = e.id
        LEFT JOIN venues v ON eb.venue_id = v.id
        LEFT JOIN countries c ON v.country_id = c.id
        WHERE eb.booking_status = 'Public'
          AND eb.air_date <= CURDATE()
          AND eb.is_deleted = 0
        ORDER BY eb.air_date DESC
        LIMIT 5
    ";
    return $db->query($sql);
}

// --- Fetch event logo grid ---
function getEventsWithPublicBookings($db) {
    $sql = "
        SELECT id, image_path, short_name, name
        FROM events
        WHERE is_deleted = 0
        AND EXISTS (
            SELECT 1 FROM event_bookings 
            WHERE event_id = events.id 
              AND is_deleted = 0 
              AND booking_status = 'Public'
        )
        ORDER BY name ASC
    ";
    return $db->query($sql)->fetch_all(MYSQLI_ASSOC);
}

// Count public event bookings
function countPublicEventBookings($db) {
    $sql = "SELECT COUNT(*) AS total FROM event_bookings WHERE booking_status = 'Public' AND is_deleted = 0";
    return $db->query($sql)->fetch_assoc()['total'] ?? 0;
}

$publicEventCount = countPublicEventBookings($db);
$recentEvents = fetchRecentPublicEvents($db);
$events = getEventsWithPublicBookings($db);
?>

<div class="site-content">
  <div class="content-box">
    <h2 class="chronology-title">LATEST EVENT RESULTS</h2><br>
    <?php if ($recentEvents->num_rows === 0): ?>
      <p>No recent public events to display.</p>
    <?php else: ?>
      <table class="win-loss-table event-archive-table">
        <thead>
          <tr>
            <th>Logo</th>
            <th>Show</th>
            <th>Air Date</th>
            <th>Location</th>
          </tr>
        </thead>
        <tbody>
          <?php while ($row = $recentEvents->fetch_assoc()): ?>
            <tr>
              <td>
                <?php if (!empty($row['logo_file'])): ?>
                  <a href="/event/<?= htmlspecialchars($row['event_booking_id']) ?>">
                    <img 
                      src="/uploads/show-logos/<?= htmlspecialchars($row['logo_file']) ?>" 
                      alt="<?= htmlspecialchars($row['show_name']) ?> Logo" 
                      style="max-height:50px; max-width:100px; object-fit:contain;"
                    >
                  </a>
                <?php else: ?>&mdash;<?php endif; ?>
              </td>
              <td>
                <a href="/event/<?= htmlspecialchars($row['event_booking_id']) ?>" class="character-link">
                  <?= htmlspecialchars($row['show_name']) ?>: <?= htmlspecialchars($row['event_label']) ?>
                </a>
              </td>
              <td><?= date('F j, Y', strtotime($row['air_date'])) ?></td>
              <td>
                <?php 
                  $parts = [];
                  if (!empty($row['venue_name']))    $parts[] = $row['venue_name'];
                  if (!empty($row['venue_location'])) $parts[] = $row['venue_location'];
                  if (!empty($row['country_name']))   $parts[] = $row['country_name'];
                  echo !empty($parts) 
                       ? htmlspecialchars(implode(' — ', $parts)) 
                       : '&mdash;'; 
                ?>
              </td>
            </tr>
          <?php endwhile; ?>
        </tbody>
      </table>
    <?php endif; ?>
  </div>

  <div class="site-content">
    <h2 class="chronology-title">FULL EVENT LIBRARY</h2>
    <br><center>Search the <b><?= $publicEventCount ?></b> episodes in the event library below.</center><br>
    <p align="center"><input type="text" id="searchBar" placeholder="Search events..."></p>

    <div class="event-grid" id="categoryGrid">
      <?php foreach ($categories as $cat): ?>
        <div class="event-card">
          <a href="/event-category/<?= urlencode($cat['name']) ?>">
            <?php if (!empty($cat['image_path'])): ?>
              <img src="/uploads/category-logos/<?= htmlspecialchars($cat['image_path']) ?>" alt="<?= htmlspecialchars($cat['name']) ?>">
            <?php else: ?>
              <div style="border:1px solid #ccc; padding:20px; text-align:center;">
                <?= htmlspecialchars($cat['name']) ?>
              </div>
            <?php endif; ?>
          </a>
        </div>
      <?php endforeach; ?>
      
      </div>
    </div>

    <div class="event-grid" id="eventGrid" style="display:none;">
      <?php foreach ($events as $event): ?>
        <div class="event-card" data-name="<?= htmlspecialchars(strtolower($event['name'])) ?>">
          <a href="/events/<?= urlencode($event['short_name']) ?>">
            <img src="/uploads/show-logos/<?= htmlspecialchars($event['image_path']) ?>" alt="<?= htmlspecialchars($event['name']) ?> Logo">
          </a>
        </div>
      <?php endforeach; ?>
    </div>

    <script>
      const searchInput = document.getElementById('searchBar');
      const categoryGrid = document.getElementById('categoryGrid');
      const eventGrid = document.getElementById('eventGrid');

      searchInput.addEventListener('input', function() {
        const value = this.value.toLowerCase();
        if (value === '') {
          categoryGrid.style.display = 'flex';
          eventGrid.style.display = 'none';
        } else {
          categoryGrid.style.display = 'none';
          eventGrid.style.display = 'flex';
          document.querySelectorAll('#eventGrid .event-card').forEach(card => {
            card.style.display = card.dataset.name.includes(value) ? 'block' : 'none';
          });
        }
      });
    </script>

</div>
