<?php
require_once __DIR__ . '/../config/db.php';


$categoryRaw = $_GET['category'] ?? '';
$category = urldecode(str_replace('+', ' ', trim($categoryRaw)));

if ($category === '') {
    echo "<h2>Category not specified.</h2>";
    exit;
}

$slug = urldecode(str_replace('+', ' ', $_GET['category'] ?? ''));

$stmt = $db->prepare("
    SELECT 
        eb.id AS event_booking_id,
        e.name AS show_name,
        e.short_name,
        eb.label AS event_label,
        eb.air_date AS air_date,
        COALESCE(NULLIF(eb.custom_image_path, ''), e.image_path) AS logo_file
    FROM event_bookings eb
    INNER JOIN events e ON eb.event_id = e.id
    WHERE eb.booking_status = 'Public'
      AND eb.air_date <= CURDATE()
      AND eb.is_deleted = 0
      AND (
          (e.categories = ?)
          OR (? = 'none' AND (e.categories IS NULL OR e.categories = '' OR e.categories = 'NONE'))
      )
    ORDER BY e.name ASC
");
$stmt->bind_param("ss", $category, $category);
$stmt->execute();
$result = $stmt->get_result();

$eventLogos = [];
while ($row = $result->fetch_assoc()) {
    $key = $row['short_name'];
    $eventLogos[$key] = [
        'name' => $row['show_name'],
        'short_name' => $row['short_name'],
        'logo_file' => $row['logo_file']
    ];
}
?>

<div class="site-content">
  
    <h2 class="chronology-title"><?= htmlspecialchars(strtoupper($category)) ?> EVENTS</h2>
    <p><a href="/event-library" class="character-link">&laquo; Back to Event Library</a></p><br>

    <?php if (empty($eventLogos)): ?>
      <p>No events found in this category.</p>
    <?php else: ?>
      <p align="center"><input type="text" id="searchBar" placeholder="Search events..."></p>

      <style>
        .event-grid {
          display: flex;
          flex-wrap: wrap;
          gap: 10px;
          justify-content: center;
          margin-bottom: 2rem;
        }
        .slugrd {
          width: 70%;
          max-width: 200px;
          background: none;
          border: none;
          text-align: center;
        }
        .event-card img {
          width: 100%;
          height: auto;
          transition: transform 0.2s;
        }
        .event-card img:hover {
          transform: scale(1.05);
        }
      </style>

      <div class="event-grid" id="eventGrid">
        <?php foreach ($eventLogos as $event): ?>
          <div class="event-card" data-name="<?= htmlspecialchars(strtolower($event['name'])) ?>">
            <a href="/events/<?= urlencode($event['short_name']) ?>">
              <img src="/uploads/show-logos/<?= htmlspecialchars($event['logo_file']) ?>" alt="<?= htmlspecialchars($event['name']) ?> Logo">
            </a>
          </div>
        <?php endforeach; ?>
      </div>

      <script>
        document.getElementById('searchBar').addEventListener('input', function() {
          const value = this.value.toLowerCase();
          document.querySelectorAll('.event-card').forEach(card => {
            card.style.display = card.dataset.name.includes(value) ? 'block' : 'none';
          });
        });
      </script>
    <?php endif; ?>

</div>
